#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 void
version:              0.7.3
visibility:           public
id:                   void-0.7.3-72JC1ZJs2iULdltk7dpkuA
key:                  void-0.7.3-72JC1ZJs2iULdltk7dpkuA
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            portable
homepage:             http://github.com/ekmett/void
synopsis:             A Haskell 98 logically uninhabited data type
description:
    A Haskell 98 logically uninhabited data type, used to indicate that a given term should not exist.

category:             Data Structures
abi:                  11aace86a253cb2ec53340f0dc608899
exposed:              True
exposed-modules:      Data.Void.Unsafe
import-dirs:          /usr/lib/ghc-8.10.5/site-local/void-0.7.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/void-0.7.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/void-0.7.3
hs-libraries:         HSvoid-0.7.3-72JC1ZJs2iULdltk7dpkuA
depends:              base-4.14.2.0
haddock-interfaces:   /usr/share/doc/haskell-void/html/void.haddock
haddock-html:         /usr/share/doc/haskell-void/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

